@@ -1,14 +1,14 @@
+import importlib.resources as pkg_resources
 from json import load, loads
 from json.decoder import JSONDecodeError
 from os import getenv
 from pathlib import Path
 
-import importlib.resources as pkg_resources
 from jsonschema import validate
 from jsonschema.exceptions import ValidationError
 from ndicts.ndicts import NestedDict
 
-import menagerie
+from menagerie import schemas
 from menagerie.utils.logger import Logger
 
 __all__ = (
@@ -28,7 +28,7 @@ Settings = NestedDict({
     'themes': {
         'bootstrap': "https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css",
         'highlight_js': "https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.4.0/styles/default.min.css",
-        'navbar_color': "light"
+        'theme': "light"
     },
     'brand': {
         'app_name': "My App",
@@ -84,7 +84,7 @@ def setup_settings(config_path: Path):
         :type config_path: Path 
     """
 
-    schema = loads(pkg_resources.read_text(menagerie, 'config_schema.json'))
+    schema = loads(pkg_resources.read_text(schemas, 'config_schema.json'))
 
     try:
         config = load(config_path.open(mode='r', encoding='utf-8'))
